@@ -27,3 +27,7 @@ class PermissionConf(AppConf):
     DEFAULT_CPL_ANY_PERMISSION = False
     DEFAULT_CPL_CHANGE_PERMISSION = True
     DEFAULT_CPL_DELETE_PERMISSION = False
+
+    AUTODISCOVER_ENABLE = True
+    AUTODISCOVER_MODULE_NAME = 'perms'
+    AUTODISCOVER_VARIABLE_NAME = 'PERMISSION_LOGICS'
